@@ -1,13 +1,14 @@
+from collections.abc import Iterable
+
 import zigpy.types
 from zigpy_cc.exception import TODO
-from zigpy_cc.types import ParameterType
+from zigpy_cc.types import AddressMode, ParameterType
 
 
 class BuffaloOptions:
     def __init__(self) -> None:
         self.startIndex = None
         self.length = None
-        self.is_address = False
 
 
 class Buffalo:
@@ -27,8 +28,11 @@ class Buffalo:
         elif type == ParameterType.UINT32:
             self.write(value, 4)
         elif type == ParameterType.IEEEADDR:
-            for i in value:
-                self.write(i)
+            if isinstance(value, Iterable):
+                for i in value:
+                    self.write(i)
+            else:
+                self.write(value, 8)
         elif type == ParameterType.BUFFER:
             self.buffer += value
         elif type == ParameterType.LIST_UINT8:
@@ -37,18 +41,45 @@ class Buffalo:
         elif type == ParameterType.LIST_UINT16:
             for v in value:
                 self.write(v, 2)
+        elif type == ParameterType.LIST_NEIGHBOR_LQI:
+            for v in value:
+                self.write_neighbor_lqi(v)
         else:
-            raise TODO("write %s", ParameterType(type))
+            raise TODO(
+                "write %s, value: %s, options: %s", ParameterType(type), value, options
+            )
 
-    def write(self, value, length=1):
-        self.buffer += value.to_bytes(length, "little")
+    def write(self, value, length=1, signed=False):
+        self.buffer += value.to_bytes(length, "little", signed=signed)
+
+    def write_neighbor_lqi(self, value):
+        for i in value["extPanId"]:
+            self.write(i)
+        for i in value["extAddr"]:
+            self.write(i)
+        self.write(value["nwkAddr"], 2)
+        self.write(
+            value["deviceType"]
+            | (value["rxOnWhenIdle"] * 4)
+            | (value["relationship"] * 16)
+        )
+        self.write(value["permitJoin"])
+        self.write(value["depth"])
+        self.write(value["lqi"])
+
+    def read_parameter(self, name, type, options):
 
-    def read_parameter(self, type, options):
         if type == ParameterType.UINT8:
             res = self.read_int()
+            if name.endswith("addrmode"):
+                res = AddressMode(res)
         elif type == ParameterType.UINT16:
             res = self.read_int(2)
-            if options.is_address:
+            if (
+                name.endswith("addr")
+                or name.endswith("address")
+                or name.endswith("addrofinterest")
+            ):
                 res = zigpy.types.NWK(res)
         elif type == ParameterType.UINT32:
             res = self.read_int(4)
